@@ -34,10 +34,6 @@ __version__ = pbr.version.VersionInfo(
 
 LOG = logging.getLogger(__name__)
 
-# This is to allow for a graceful swap from oslosphinx to openstackdocstheme
-THEME = 'openstackdocstheme'
-
-
 """This provides a sphinx extension able to create the HTML needed
 for the api-ref website.
 
@@ -210,6 +206,7 @@ class RestMethodDirective(rst.Directive):
 
         return [target, section]
 
+
 # cache for file -> yaml so we only do the load and check of a yaml
 # file once during a sphinx processing run.
 YAML_CACHE = {}
@@ -335,7 +332,7 @@ class RestParametersDirective(Table):
                     else:
                         continue
 
-        if len(self.env.path_params) is not 0:
+        if len(self.env.path_params) != 0:
             # Warn that path parameters are not set in rest_parameter
             # stanza and will not appear in the generated table.
             for param in self.env.path_params:
@@ -658,9 +655,9 @@ def copy_assets(app, exception):
 
 
 def add_assets(app):
-    app.add_stylesheet('api-site.css')
-    app.add_javascript('api-site.js')
-    app.add_javascript('combobox.js')
+    app.add_css_file('api-site.css')
+    app.add_js_file('api-site.js')
+    app.add_js_file('combobox.js')
 
 
 def setup(app):
